<?php
/**
 * Plugin Name: Romega Blocks
 * Description: Custom Gutenberg blocks developed by Devhuset
 * Requires at least: 6.5
 * Requires PHP: 7.0
 * Version: 0.1.45
 * Author: Devhuset AS
 * Author URI: https://devhuset.no
 * License: GPL-2.0-or-later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: romega-blocks
 *
 * @package romega-blocks
 */

namespace RomegaBlocks;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

// Plugin Constants
define('ROMEGA_BLOCKS_VERSION', '0.1.45');
define('ROMEGA_BLOCKS_DIR', plugin_dir_path(__FILE__));
define('ROMEGA_BLOCKS_URL', plugin_dir_url(__FILE__));
define('ROMEGA_BLOCKS_BASENAME', plugin_basename(__FILE__));
define('ROMEGA_BLOCKS_RELATIVE_PLUGIN_DIR', dirname(plugin_basename(__FILE__)));
define('ROMEGA_BLOCKS_RELATIVE_PLUGIN_FILE', plugin_basename(__FILE__));

// Include the update checker
require ROMEGA_BLOCKS_DIR . 'update.php';

/**
 * Main plugin class
 */
class Plugin
{
    /**
     * Initialize the plugin
     *
     * @return void
     */
    public static function init()
    {
        add_action('init', [self::class, 'register_blocks']);
        add_action('acf/init', [self::class, 'register_acf']);
        add_filter('block_categories_all', [self::class, 'register_categories'], 10, 2);
        add_action('after_setup_theme', [self::class, 'register_image_sizes']);
        add_action('plugins_loaded', [self::class, 'check_dependencies']);

        include ROMEGA_BLOCKS_DIR . 'blocks/post-grid/post-type.php';
    }

    /**
     * Check plugin dependencies
     *
     * @return void
     */
    public static function check_dependencies()
    {
        if (!function_exists('acf_register_block_type')) {
            add_action('admin_notices', function () {
                ?>
                <div class="notice notice-error">
                    <p><?php _e('Romega Blocks requires Advanced Custom Fields PRO to be installed and activated.', 'romega-blocks'); ?>
                    </p>
                </div>
                <?php
            });
        }
    }

    /**
     * Register Gutenberg blocks
     *
     * @return void
     */
    public static function register_blocks()
    {
        if (!function_exists('acf_register_block_type')) {
            return;
        }

        $blocks_dir = ROMEGA_BLOCKS_DIR . 'blocks/';
        $block_folders = glob($blocks_dir . '*', GLOB_ONLYDIR);

        foreach ($block_folders as $folder) {
            register_block_type($folder);
        }
    }

    /**
     * Register ACF for Gutenberg blocks
     * 
     * @return void
     */
    public static function register_acf()
    {
        if (function_exists('acf_add_local_field_group')):
            $blocks_dir = ROMEGA_BLOCKS_DIR . 'blocks/';
            $block_folders = glob($blocks_dir . '*', GLOB_ONLYDIR);

            foreach ($block_folders as $folder) {
                $acf_file = $folder . '/acf.php';
                if (file_exists($acf_file)) {
                    include $acf_file;
                }
            }
        endif;
    }

    /**
     * Register custom block categories
     *
     * @param array $categories Existing categories.
     * @return array Modified categories.
     */
    public static function register_categories($categories)
    {
        return array_merge(
            $categories,
            [
                [
                    'slug' => 'viskan',
                    'title' => __('Viskan', 'romega-blocks'),
                    'icon' => 'wordpress',
                ]
            ]
        );
    }

    /**
     * Register custom image sizes
     *
     * @return void
     */
    public static function register_image_sizes()
    {
        add_image_size('product-thumb', 100, 100, false);
    }
}

Plugin::init();